@@ -1,7 +1,7 @@
 package PICA::Writer::Plain;
 use v5.14.1;
 
-our $VERSION = '1.20';
+our $VERSION = '1.21';
 
 use charnames qw(:full);
 use Term::ANSIColor;
@@ -34,9 +34,9 @@ sub write_annotation {
 
     if (@$field % 2) {
         $self->{fh}->print($field->[$#$field] . " ")
-            unless defined $self->{annotated} && !$self->{annotated};
+            unless defined $self->{annotate} && !$self->{annotate};
     }
-    elsif ($self->{annotated}) {
+    elsif ($self->{annotate}) {
         $self->{fh}->print("  ");
     }
 }
@@ -54,7 +54,4 @@ See L<PICA::Writer::Base> for synopsis and details.
 
 The counterpart of this module is L<PICA::Parser::Plain>.
 
-This writer also supports annotated PICA by default. Use option C<annotated> to
-ensure or ignore field annotations.
-
 =cut
